"use strict";
var _a, _b;
Object.defineProperty(exports, "__esModule", { value: true });
exports.filename = void 0;
const upath_1 = require("upath");
const webpack_merge_1 = require("webpack-merge");
const rules_1 = require("@ewizardjs/builder-utils/rules");
const plugins_1 = require("../plugins");
const PLUGINS_TO_REMOVE = [
    'CleanWebpackPlugin',
    'ValidateContentPathsPlugin',
];
const RULES_TO_REMOVE = [
    (_a = rules_1.images({ options: {} }).test) === null || _a === void 0 ? void 0 : _a.toString(),
    (_b = rules_1.media({ options: {} }).test) === null || _b === void 0 ? void 0 : _b.toString(),
];
const addPublicPath = (p) => {
    return `(window.__publicPath || '') + ${p}`;
};
exports.filename = 'build/dev/components-list.js';
exports.default = (presentationPath, config) => {
    const componentsListConfig = getComponentsListConfig(presentationPath);
    const ComponentsLibraryConfig = webpack_merge_1.mergeWithCustomize({
        customizeArray(item1, item2, key) {
            if (key === 'plugins') {
                const defaultPlugins = item1;
                const templatesPlugins = item2;
                return removePlugins(defaultPlugins).concat(templatesPlugins);
            }
            if (key === 'module.rules') {
                const defaultRules = item1;
                const templatesRules = item2;
                return removeRules(defaultRules).concat(templatesRules);
            }
        },
    })(config, componentsListConfig);
    return [ComponentsLibraryConfig, config];
};
function getComponentsListConfig(presentationPath) {
    return {
        entry: require.resolve('../../assets/components-list.js'),
        mode: 'production',
        devtool: false,
        output: {
            filename: exports.filename,
            library: 'ComponentsList',
            libraryTarget: 'window',
        },
        performance: {
            hints: false,
        },
        module: {
            rules: [
                rules_1.images({
                    options: {
                        emitFile: false,
                        postTransformPublicPath: addPublicPath,
                        useRequire: false,
                    },
                }),
                rules_1.media({
                    options: {
                        emitFile: false,
                        postTransformPublicPath: addPublicPath,
                    },
                }),
                {
                    test: /template\.vue$/i,
                    use: [{
                            loader: require.resolve('../loaders/vue-component-to-module-loader'),
                        }],
                },
            ],
        },
        plugins: [
            plugins_1.cleanDestinationFolder([upath_1.join(presentationPath, exports.filename)]),
            new plugins_1.InjectComponentsListToHtmlPlugin(presentationPath),
        ],
    };
}
function removePlugins(plugins = []) {
    return plugins
        .filter(plugin => plugin.constructor && !PLUGINS_TO_REMOVE.includes(plugin.constructor.name));
}
function removeRules(rules = []) {
    return rules.filter(rule => rule.test && !RULES_TO_REMOVE.includes(rule.test.toString()));
}
//# sourceMappingURL=webpack.config.js.map