"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const pages_api_1 = require("@ewizardjs/pages-api");
const fs_extra_1 = require("fs-extra");
const path_1 = require("path");
const ramda_1 = require("ramda");
const content_types_1 = require("@ewizardjs/content-types");
async function default_1(systemSettings, baseDir, { fileProps, filePathProps, componentsPackageName }) {
    const contentType = ramda_1.pathOr('', ['content', 'type'], systemSettings);
    const blocksDir = ramda_1.pathOr('', ['path', 'blocks'], systemSettings);
    const localBlocksDir = ramda_1.pathOr('', ['path', 'localBlocks'], systemSettings);
    const rootComponentPath = ramda_1.pathOr('', ['path', 'rootComponent'], systemSettings);
    const pagesComponentPath = await getPagesComponentsPath(baseDir, systemSettings);
    const rootComponentLoaderConfig = {
        test: new RegExp(rootComponentPath),
        use: [
            {
                loader: require.resolve('./loaders/template-loader'),
                options: {
                    baseDir,
                    fileProps,
                    filePathProps,
                    componentsPackageName,
                    componentType: 'root',
                    id: 'app',
                },
            },
        ],
    };
    const blockComponentLoaderConfig = {
        test: /index\.vue$/,
        include: [path_1.resolve(baseDir, blocksDir), path_1.resolve(baseDir, localBlocksDir)],
        use: [
            {
                loader: require.resolve('./loaders/template-loader'),
                options: {
                    baseDir,
                    filePathProps,
                    componentsPackageName,
                    componentType: 'block',
                    paths: [path_1.resolve(baseDir, blocksDir), path_1.resolve(baseDir, localBlocksDir)],
                },
            },
        ],
    };
    switch (contentType) {
        case content_types_1.ContentTypes.EMAIL:
        case content_types_1.ContentTypes.MODULE:
            return [
                blockComponentLoaderConfig,
                rootComponentLoaderConfig,
            ];
        case content_types_1.ContentTypes.SURVEY:
        case content_types_1.ContentTypes.EDETAILER:
            const slideLoaders = {
                test: /slides.*index\.vue$/,
                use: [
                    {
                        loader: require.resolve('./loaders/template-loader'),
                        options: {
                            baseDir,
                            fileProps,
                            filePathProps,
                            componentsPackageName,
                            componentType: 'slide',
                        },
                    },
                ],
            };
            return [slideLoaders, rootComponentLoaderConfig];
        case content_types_1.ContentTypes.SITE:
        case content_types_1.ContentTypes.MESSENGER_AD:
            const pageComponentLoadersConfig = {
                include: pagesComponentPath,
                use: [
                    {
                        loader: require.resolve('./loaders/template-loader'),
                        options: {
                            baseDir,
                            fileProps,
                            filePathProps,
                            componentsPackageName,
                            componentType: 'page',
                        },
                    },
                ],
            };
            return [
                blockComponentLoaderConfig,
                pageComponentLoadersConfig,
                rootComponentLoaderConfig,
            ];
        case content_types_1.ContentTypes.JOURNEY:
            return [
                rootComponentLoaderConfig,
            ];
        default:
            return [];
    }
}
exports.default = default_1;
async function getPagesComponentsPath(contentPath, systemSettings) {
    const pagesJson = await getPagesJson(contentPath);
    return pages_api_1.getFlatPages(pagesJson, undefined, systemSettings)
        .map(({ template }) => path_1.resolve(contentPath, template));
}
async function getPagesJson(contentPath) {
    try {
        const pagesJsonPath = path_1.join(contentPath, 'pages.json');
        return await fs_extra_1.readJSON(pagesJsonPath);
    }
    catch (e) {
        return {};
    }
}
//# sourceMappingURL=get-template-loaders.js.map